aboutsummaryrefslogtreecommitdiff
path: root/R/nlme.mmkin.R
diff options
context:
space:
mode:
authorJohannes Ranke <jranke@uni-bremen.de>2020-11-09 17:24:53 +0100
committerJohannes Ranke <jranke@uni-bremen.de>2020-11-09 17:24:53 +0100
commitaa74f5a30853fb0a15c99c283e072f08ee819149 (patch)
tree988ec89e22b48fff4544653a4c3443356bab3071 /R/nlme.mmkin.R
parenta1631098acfc3352e19c331e568bd6f5766b3c3d (diff)
saemix.mmkin and nlme.mmkin inherit from mixed.mmkin
With a plot method. The class mixed.mmkin is currently only a virtual class created to unify the plotting method.
Diffstat (limited to 'R/nlme.mmkin.R')
-rw-r--r--R/nlme.mmkin.R9
1 files changed, 5 insertions, 4 deletions
diff --git a/R/nlme.mmkin.R b/R/nlme.mmkin.R
index 695c63e9..8d875fee 100644
--- a/R/nlme.mmkin.R
+++ b/R/nlme.mmkin.R
@@ -43,13 +43,14 @@ get_deg_func <- function() {
#' @param control passed to nlme
#' @param verbose passed to nlme
#' @importFrom stats na.fail as.formula
#' @return Upon success, a fitted nlme.mmkin object, which is an nlme object
#' with additional elements
#' @note As the object inherits from [nlme::nlme], there is a wealth of
#' methods that will automatically work on 'nlme.mmkin' objects, such as
#' [nlme::intervals()], [nlme::anova.lme()] and [nlme::coef.lme()].
#' @export
-#' @seealso [nlme_function()]
+#' @seealso [nlme_function()], [plot.mixed.mmkin], [summary.nlme.mmkin],
+#' [parms.nlme.mmkin]
#' @examples
#' ds <- lapply(experimental_data_for_UBA_2019[6:10],
#' function(x) subset(x$data[c("name", "time", "value")], name == "parent"))
@@ -203,7 +204,7 @@ nlme.mmkin <- function(model, data = sys.frame(sys.parent()),
val$nlmeversion <- as.character(utils::packageVersion("nlme"))
val$mkinversion <- as.character(utils::packageVersion("mkin"))
val$Rversion <- paste(R.version$major, R.version$minor, sep=".")
- class(val) <- c("nlme.mmkin", "nlme", "lme")
+ class(val) <- c("nlme.mmkin", "mixed.mmkin", "nlme", "lme")
return(val)
}
@@ -43,13 +43,14 @@ get_deg_func <- function() {
#' @param verbose passed to nlme
#' @importFrom stats na.fail as.formula
-#' @return Upon success, a fitted nlme.mmkin object, which is an nlme object
-#' with additional elements
+#' @return Upon success, a fitted 'nlme.mmkin' object, which is an nlme object
+#' with additional elements. It also inherits from 'mixed.mmkin'.
#' @note As the object inherits from [nlme::nlme], there is a wealth of
#' methods that will automatically work on 'nlme.mmkin' objects, such as

Contact - Imprint